#ifdef __linux__
#include <boost/shared_ptr.hpp>
#include <boost/bind.hpp>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <sys/kd.h> 
#include <sys/stat.h>
#include <sys/mman.h>
#include <sys/types.h>
#include <sys/time.h>

#include "time.h"
#include "command.h"
#include "common.h"
#include "console.h"

unsigned int getSystemCallDelay( int _console ) {
  struct timeval tv[ DELAY_DETECTION_SAMPLE_NUM ];
  int counter;
  for( counter = 0; counter != DELAY_DETECTION_SAMPLE_NUM; counter++ ) {
    ioctl( _console, KIOCSOUND, 0 );
    gettimeofday(tv + counter, NULL);
  }
  unsigned int system_call_delay = 0;
  int sample_num = DELAY_DETECTION_SAMPLE_NUM - 1;
  for( counter = 0; counter != DELAY_DETECTION_SAMPLE_NUM - 1; counter++ ) {
    if( tv[ counter + 1 ].tv_sec == tv[ counter ].tv_sec )
      system_call_delay += tv[ counter + 1 ].tv_usec - tv[ counter ].tv_usec;
    else if( tv[ counter + 1 ].tv_sec == tv[ counter ].tv_sec + 1 ) {
       system_call_delay += 1000000 + tv[ counter + 1 ].tv_usec - tv[ counter ].tv_usec;
    }
    else {
      sample_num--;
    }
  }
  system_call_delay /= sample_num;
  return system_call_delay;
}

NoizeGenerator::NoizeGenerator( unsigned int _console ) : system_call_delay( getSystemCallDelay( _console ) ), console( _console ) {
  generateRandomTable();
}
void NoizeGenerator::play( uint32_t _usec ) const {
    int call_times = _usec / system_call_delay;
    int counter;
    for( counter = 0; counter != call_times; counter++ )
      ioctl( console, KIOCSOUND,
             ( ( noize_table[ ( counter >> 4 ) & ( NOIZE_TABLE_SIZE - 1 ) ] >> ( counter & 0x0F ) ) & 0x01 ) << 14 );
}
void NoizeGenerator::generateRandomTable() {
  int counter;
  srandom( system_call_delay );
  if( RAND_MAX >= 0xFFFF ) {
    for( counter = 0; counter != NOIZE_TABLE_SIZE; counter++ ) {
      noize_table[ counter ] = ( random() >> 8 ) & 0xFFFF;
    }
  }
  else {
    for( counter = 0; counter != NOIZE_TABLE_SIZE; counter++ ) {
      noize_table[ counter ] = random() & 0xFFFF;
    }
  }
  random_sum = 0;
  for( counter = 0; counter != NOIZE_TABLE_SIZE; counter++ ) {
    random_sum += noize_table[ counter ];
  }
}

    ConsoleBeep::ConsoleBeep( const char *_device_name )
    : current_tone( -1 ), console( open( _device_name, O_WRONLY ) ), noize_generator( console ),
      destroyer( (int*)NULL, boost::bind( &ConsoleBeep::destroy, _1, console ) ) {
      if( !console )
        throw -1;
    }
    void ConsoleBeep::setTone( int _new_tone ) {
      _new_tone &= 0x7F;
      _new_tone -= lowest_note_number;
      if( _new_tone > 0 ) {
        if( current_tone == -1 ) {
          write( console, set_length, SET_LENGTH_COMMAND_SIZE );
        }
        if( current_tone != _new_tone ) {
          write( console, freq[ _new_tone ], SET_FREQ_COMMAND_SIZE );
          current_tone = _new_tone;
        }
      }
      else {
        write( console, set_stop, SET_STOP_COMMAND_SIZE );
        current_tone = -1;
      }
    }
    double ConsoleBeep::getTime() const {
      struct timeval tv;
      gettimeofday( &tv, NULL );
      return static_cast< double >( tv.tv_sec ) + static_cast< double >( tv.tv_usec ) * 0.000001;
    }
    void ConsoleBeep::sleep( double _until ) const {
      long int sleep_time = static_cast< long int >( ( _until - getTime() ) * 1000000 );
      usleep( sleep_time );
    }
    void ConsoleBeep::noize( double _until ) const {
      long int noize_time = static_cast< long int >( ( _until - getTime() ) * 1000000 );
      noize_generator.play( noize_time );
    }
    void ConsoleBeep::destroy( int *_dummy, unsigned int _console ) {
      write( _console, set_stop, SET_STOP_COMMAND_SIZE );
      close( _console );
    }
#endif
