#ifndef BEEP_CONSOLE_H
#define BEEP_CONSOLE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#ifdef __linux__

#include <boost/shared_ptr.hpp>
#include <boost/bind.hpp>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <sys/kd.h> 
#include <sys/stat.h>
#include <sys/mman.h>
#include <sys/types.h>
#include <sys/time.h>

#include "time.h"
#include "common.h"

#define DELAY_DETECTION_SAMPLE_NUM      128
#define NOIZE_TABLE_SIZE 4096

unsigned int getSystemCallDelay( int _console );
class NoizeGenerator {
  public:
    NoizeGenerator( unsigned int _console );
    void play( uint32_t _usec ) const;
  private:
    void generateRandomTable();
    const unsigned int system_call_delay;
    unsigned int noize_table[ NOIZE_TABLE_SIZE ];
    unsigned int random_sum;
    unsigned int console;
};

class ConsoleBeep {
  public:
    ConsoleBeep( const char *_device_name );
    void setTone( int _new_tone );
    double getTime() const;
    void sleep( double _until ) const;
    void noize( double _until ) const;
  private:
    static void destroy( int *_dummy, unsigned int _console );
    int current_tone;
    const int console;
    NoizeGenerator noize_generator;
    boost::shared_ptr< int > destroyer;
};

#endif

#endif
