#ifndef BEEP_READER_H
#define BEEP_READER_H

#include <list>

#include "note_data.h"
#include "common.h"

template< typename PolyphonyType >
class Reader {
  public:
    struct NoteMapData {
      typename PolyphonyType::SlotID id;
      unsigned int until;
    };
    Reader( const char *_console, unsigned int _tempo, const NoteData *_uhead, const NoteData *_lhead, const NoteData *_dhead ) :
    polyphony( _console ),
    tempo( _tempo ), uhead( _uhead ), ucurrent( _uhead ),
    lhead( _lhead ), lcurrent( _lhead ),
    dhead( _dhead ), dcurrent( _dhead ), end_flag( false ), since( 0 ) {
    }
    void operator()() {
      if( end_flag == false ) {
        for( ; ucurrent->time < since; ucurrent++ ) {
          if( ucurrent->level == 0.0 ) {
            end_flag = true;
          }
          NoteMapData md;
          md.id = polyphony.noteOn( ucurrent->note_number, 0 );
          md.until = ucurrent->length;
          map.push_back( md );
        }
        for( ; lcurrent->time < since; lcurrent++ ) {
          if( lcurrent->level == 0.0 ) {
            end_flag = true;
          }
          NoteMapData md;
          md.id = polyphony.noteOn( lcurrent->note_number, 1 );
          md.until = lcurrent->length;
          map.push_back( md );
        }
        bool dup_drum = false;
        for( ; dcurrent->time < since; dcurrent++ ) {
          if( dcurrent->level == 0.0 ) {
            end_flag = true;
          }
          if( !dup_drum ) {
            NoteMapData md;
            md.id = polyphony.noteOn( 0, 2 );
            md.until = 1;
            map.push_back( md );
            dup_drum = true;
          }
        }
        polyphony( 1.0/((tempo/60.0)*8.0) );
        typename std::list< NoteMapData >::iterator iter;
        for( iter = map.begin(); iter != map.end(); ) {
          iter->until--;
          if( !iter->until ) {
            polyphony.noteOff( iter->id );
            iter = map.erase( iter );
          }
          else
            iter++;
        }
        since++;
      }
    }
    bool isEnd() const { return end_flag; }
  private:
    PolyphonyType polyphony;
    unsigned int tempo;
    const NoteData *uhead;
    const NoteData *ucurrent;
    const NoteData *lhead;
    const NoteData *lcurrent;
    const NoteData *dhead;
    const NoteData *dcurrent;
    bool end_flag;
    unsigned int since;
    std::list< NoteMapData > map;
};

#endif
