#ifndef SAMPLE_SCORE_H
#define SAMPLE_SCORE_H
#include "note_data.h"
#include "common.h"
class EPianoEnvelope : public Envelope {
  public:
    void noteOn() {
      state = NOTE_ON;
    }
    void noteOff( float _time ) {
      note_off_time = _time;
      state = NOTE_OFF;
    }
    float get( float _time ) {
      if( state == NOTE_ON ) {
        static const unsigned int image_size = 20;
        static const float image[ image_size ] = {
          1.0, 1.0, 1.0, 0.9, 0.9, 0.8, 0.7, 0.6, 0.5, 0.4,
          0.3, 0.2, 0.1, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0,
        };
        _time *= 2.0f;
        unsigned int pos = _time * image_size;
        if( pos >= image_size ) pos = image_size - 1;
        last_level = image[ pos ];
        return last_level;
      }
      else {
        _time *= 4.0f;
        return std::max( last_level - last_level * _time, 0.0f );
      }
    }
  private:
    NoteState state;
    float note_off_time;
    float last_level;
};

class PianoEnvelope : public Envelope {
  public:
    void noteOn() {
      state = NOTE_ON;
    }
    void noteOff( float _time ) {
      note_off_time = _time;
      state = NOTE_OFF;
    }
    float get( float _time ) {
      if( state == NOTE_ON ) {
        static const unsigned int image_size = 20;
        static const float image[ image_size ] = {
          0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0,
          0.975, 0.95, 0.925, 0.90, 0.875, 0.85, 0.825, 0.80, 0.775, 0.75,
        };
        _time *= 6.0f;
        unsigned int pos = _time * image_size;
        if( pos >= image_size ) pos = image_size - 1;
        last_level = image[ pos ];
        return last_level;
      }
      else {
        _time *= 4.0f;
        return std::max( last_level - last_level * _time, 0.0f );
      }
    }
  private:
    NoteState state;
    float note_off_time;
    float last_level;
};

class DrumEnvelope : public Envelope {
  public:
    void noteOn() {
      state = NOTE_ON;
      on = true;
    }
    void noteOff( float _time ) {
      state = NOTE_OFF;
      on = false;
    }
    float get( float _time ) {
      if( on ) {
        on = false;
        return 0.5f;
      }
      else {
        return 0.0f;
      }
    }
  private:
    NoteState state;
    bool on;
};



// ピアノ楽譜
static const NoteData piano_score[] = {
  // 0
  NOTE ( 0.0, 0.5, 58 ),
  NOTE ( 0.0, 0.5, 55 ),
  NOTE ( 0.0, 0.5, 50 ),
  NOTE ( 1.5, 0.5, 58 ),
  NOTE ( 1.5, 0.5, 55 ),
  NOTE ( 1.5, 0.5, 50 ),
  // 1
  NOTE ( 5.0, 0.5, 67 ),
  NOTE ( 5.0, 0.5, 58 ),
  NOTE ( 5.0, 0.5, 51 ),
  NOTE ( 6.5, 1.5, 69 ),
  NOTE ( 6.5, 1.5, 60 ),
  NOTE ( 6.5, 1.5, 53 ),
  // 2
  NOTE ( 9.0, 0.5, 70 ),
  NOTE ( 9.0, 0.5, 62 ),
  NOTE ( 9.0, 0.5, 55 ),
  NOTE ( 10.5, 1.5, 69 ),
  NOTE ( 10.5, 1.5, 60 ),
  NOTE ( 10.5, 1.5, 53 ),
  // 3
  NOTE ( 13.0, 0.5, 67 ),
  NOTE ( 13.0, 0.5, 58 ),
  NOTE ( 13.0, 0.5, 51 ),
  NOTE ( 14.5, 1.5, 69 ),
  NOTE ( 14.5, 1.5, 60 ),
  NOTE ( 14.5, 1.5, 53 ),
  // 4
  NOTE ( 16.0, 0.5, 70 ),
  NOTE ( 16.0, 0.5, 62 ),
  NOTE ( 16.0, 0.5, 55 ),
  NOTE ( 18.25, 0.25, 67 ),
  NOTE ( 18.5, 1.0, 69 ),
  NOTE ( 18.5, 1.0, 60 ),
  NOTE ( 18.5, 1.0, 53 ),
  NOTE ( 19.5, 0.5, 69 ),
  NOTE ( 19.5, 0.5, 60 ),
  NOTE ( 19.5, 0.5, 53 ),
  // 5
  NOTE ( 21.0, 0.5, 67 ),
  NOTE ( 21.0, 0.5, 58 ),
  NOTE ( 21.0, 0.5, 51 ),
  NOTE ( 22.5, 1.5, 69 ),
  NOTE ( 22.5, 1.5, 60 ),
  NOTE ( 22.5, 1.5, 53 ),
  // 6
  NOTE ( 25.0, 0.5, 70 ),
  NOTE ( 25.0, 0.5, 62 ),
  NOTE ( 25.0, 0.5, 55 ),
  NOTE ( 26.5, 1.5, 69 ),
  NOTE ( 26.5, 1.5, 60 ),
  NOTE ( 26.5, 1.5, 53 ),
  // 7
  NOTE ( 29.0, 0.5, 67 ),
  NOTE ( 29.0, 0.5, 58 ),
  NOTE ( 29.0, 0.5, 51 ),
  NOTE ( 30.5, 1.0, 69 ),
  NOTE ( 30.5, 1.5, 60 ),
  NOTE ( 30.5, 1.5, 53 ),
  NOTE ( 31.5, 0.25, 67 ),
  NOTE ( 31.75, 0.25, 69 ),
  // 8
  NOTE ( 32.0, 0.5, 70 ),
  NOTE ( 32.0, 0.5, 62 ),
  NOTE ( 32.0, 0.5, 55 ),
  NOTE ( 33.5, 1.5, 72 ),
  NOTE ( 33.5, 1.5, 62 ),
  NOTE ( 33.5, 1.5, 55 ),
  NOTE ( 35.0, 0.5, 70 ),
  NOTE ( 35.0, 0.5, 62 ),
  NOTE ( 35.0, 0.5, 55 ),
  // 9
  NOTE ( 37.0, 0.5, 67 ),
  NOTE ( 37.0, 0.5, 58 ),
  NOTE ( 37.0, 0.5, 51 ),
  NOTE ( 38.5, 1.5, 69 ),
  NOTE ( 38.5, 1.5, 60 ),
  NOTE ( 38.5, 1.5, 53 ),
  // 10
  NOTE ( 41.0, 0.5, 70 ),
  NOTE ( 41.0, 0.5, 62 ),
  NOTE ( 41.0, 0.5, 55 ),
  NOTE ( 42.5, 1.5, 69 ),
  NOTE ( 42.5, 1.5, 60 ),
  NOTE ( 42.5, 1.5, 53 ),
  // 11
  NOTE ( 45.0, 0.5, 67 ),
  NOTE ( 45.0, 0.5, 58 ),
  NOTE ( 45.0, 0.5, 51 ),
  NOTE ( 46.5, 1.5, 69 ),
  NOTE ( 46.5, 1.5, 60 ),
  NOTE ( 46.5, 1.5, 53 ),
  // 12
  NOTE ( 48.0, 0.5, 70 ),
  NOTE ( 48.0, 0.5, 62 ),
  NOTE ( 48.0, 0.5, 55 ),
  NOTE ( 50.25, 0.25, 67 ),
  NOTE ( 50.5, 1.0, 69 ),
  NOTE ( 50.5, 1.0, 60 ),
  NOTE ( 50.5, 1.0, 53 ),
  NOTE ( 51.5, 0.5, 69 ),
  NOTE ( 51.5, 0.5, 60 ),
  NOTE ( 51.5, 0.5, 53 ),
  // 13
  NOTE ( 53.0, 0.5, 67 ),
  NOTE ( 53.0, 0.5, 58 ),
  NOTE ( 53.0, 0.5, 51 ),
  NOTE ( 54.5, 1.5, 54 ),
  NOTE ( 54.5, 1.5, 69 ),
  NOTE ( 54.5, 1.5, 60 ),
  // 14
  NOTE ( 57.0, 0.5, 70 ),
  NOTE ( 57.0, 0.5, 62 ),
  NOTE ( 57.0, 0.5, 55 ),
  NOTE ( 58.5, 1.5, 69 ),
  NOTE ( 58.5, 1.5, 60 ),
  NOTE ( 58.5, 1.5, 53 ),
  // 15
  NOTE ( 61.0, 0.5, 67 ),
  NOTE ( 61.0, 0.5, 58 ),
  NOTE ( 61.0, 0.5, 51 ),
  NOTE ( 62.5, 1.0, 69 ),
  NOTE ( 62.5, 1.5, 60 ),
  NOTE ( 62.5, 1.5, 53 ),
  NOTE ( 63.5, 0.25, 67 ),
  NOTE ( 63.75, 0.25, 69 ),
  // 16
  NOTE ( 64.0, 0.5, 70 ),
  NOTE ( 64.0, 0.5, 62 ),
  NOTE ( 64.0, 0.5, 55 ),
  NOTE ( 65.5, 1.5, 72 ),
  NOTE ( 65.5, 1.5, 62 ),
  NOTE ( 65.5, 1.5, 55 ),
  NOTE ( 67.0, 0.5, 70 ),
  NOTE ( 67.0, 0.5, 62 ),
  NOTE ( 67.0, 0.5, 55 ),
  // 17
  NOTE ( 69.0, 0.5, 67 ),
  NOTE ( 69.0, 0.5, 58 ),
  NOTE ( 69.0, 0.5, 51 ),
  NOTE ( 70.5, 1.5, 69 ),
  NOTE ( 70.5, 1.5, 60 ),
  NOTE ( 70.5, 1.5, 53 ),
  // 18
  NOTE ( 73.0, 0.5, 70 ),
  NOTE ( 73.0, 0.5, 62 ),
  NOTE ( 73.0, 0.5, 55 ),
  NOTE ( 74.5, 1.5, 69 ),
  NOTE ( 74.5, 1.5, 60 ),
  NOTE ( 74.5, 1.5, 53 ),
  // 19
  NOTE ( 77.0, 0.5, 67 ),
  NOTE ( 77.0, 0.5, 58 ),
  NOTE ( 77.0, 0.5, 51 ),
  NOTE ( 78.5, 1.5, 69 ),
  NOTE ( 78.5, 1.5, 60 ),
  NOTE ( 78.5, 1.5, 53 ),
  // 20
  NOTE ( 80.0, 0.5, 70 ),
  NOTE ( 80.0, 0.5, 62 ),
  NOTE ( 80.0, 0.5, 55 ),
  NOTE ( 82.25, 0.25, 67 ),
  NOTE ( 82.5, 1.0, 69 ),
  NOTE ( 82.5, 1.0, 60 ),
  NOTE ( 82.5, 1.0, 53 ),
  NOTE ( 83.5, 0.5, 69 ),
  NOTE ( 83.5, 0.5, 60 ),
  NOTE ( 83.5, 0.5, 53 ),
  // 21
  NOTE ( 85.0, 0.5, 67 ),
  NOTE ( 85.0, 0.5, 58 ),
  NOTE ( 85.0, 0.5, 51 ),
  NOTE ( 86.5, 1.5, 54 ),
  NOTE ( 86.5, 1.5, 69 ),
  NOTE ( 86.5, 1.5, 60 ),
  // 22
  NOTE ( 89.0, 0.5, 70 ),
  NOTE ( 89.0, 0.5, 62 ),
  NOTE ( 89.0, 0.5, 5 ),
  NOTE ( 90.5, 1.5, 69 ),
  NOTE ( 90.5, 1.5, 60 ),
  NOTE ( 90.5, 1.5, 53 ),
  // 23
  NOTE ( 93.0, 0.5, 67 ),
  NOTE ( 93.0, 0.5, 58 ),
  NOTE ( 93.0, 0.5, 51 ),
  NOTE ( 94.5, 1.0, 69 ),
  NOTE ( 94.5, 1.5, 60 ),
  NOTE ( 94.5, 1.5, 53 ),
  NOTE ( 95.5, 0.25, 67 ),
  NOTE ( 95.75, 0.25, 69 ),
  // 24
  NOTE ( 96.0, 0.5, 70 ),
  NOTE ( 96.0, 0.5, 62 ),
  NOTE ( 96.0, 0.5, 55 ),
  NOTE ( 97.5, 1.0, 72 ),
  NOTE ( 97.5, 1.5, 62 ),
  NOTE ( 97.5, 1.5, 55 ),
  NOTE ( 99.0, 0.25, 70 ),
  NOTE ( 99.0, 0.25, 62 ),
  NOTE ( 99.0, 0.25, 55 ),


  END_NOTE( 104 )
};

// エレクトリックピアノ楽譜
static const NoteData epiano_score[] = {
  // 1
  NOTEL ( 4.0, 2.0, 67 ),
  NOTEL ( 4.25, 2.75, 70 ),
  NOTEL ( 4.5, 2.5, 75 ),
  NOTEL ( 6.76, 0.25, 72 ),
  NOTEL ( 7.0, 0.25, 70 ),
  NOTEL ( 7.25, 0.25, 69 ),
  NOTEL ( 7.5, 0.25, 65 ),
  NOTEL ( 7.75, 0.25, 69 ),
  // 2
  NOTEL ( 8.0, 1.0, 67 ),
  NOTEL ( 8.25, 1.0, 70 ),
  NOTEL ( 8.5, 1.0, 74 ),
  NOTEL ( 10.5, 1.5, 72 ),
  NOTEL ( 10.5, 1.5, 69 ),
  NOTEL ( 10.5, 1.5, 65 ),
  // 3
  NOTEL ( 12.0, 2.0, 63 ),
  NOTEL ( 12.25, 1.75, 67 ),
  NOTEL ( 12.5, 1.5, 70 ),
  NOTEL ( 14.0, 2.0, 65 ),
  NOTEL ( 14.25, 1.75, 69 ),
  NOTEL ( 14.5, 1.5, 72 ),
  // 4
  NOTEL ( 16.0, 0.75, 74 ),
  NOTEL ( 16.0, 0.75, 70 ),
  NOTEL ( 16.0, 0.75, 67 ),
  NOTEL ( 18.5, 1.5, 72 ),
  NOTEL ( 18.5, 1.5, 69 ),
  NOTEL ( 18.5, 1.5, 65 ),
  // 5
  NOTEL ( 20.0, 2.0, 67 ),
  NOTEL ( 20.25, 1.75, 70 ),
  NOTEL ( 20.5, 1.5, 75 ),
  NOTEL ( 22.75, 0.25, 72 ),
  NOTEL ( 23.0, 0.25, 70 ),
  NOTEL ( 23.25, 0.25, 69 ),
  NOTEL ( 23.5, 0.25, 66 ),
  NOTEL ( 23.75, 0.25, 69 ),
  // 6
  NOTEL ( 24.0, 1.0, 67 ),
  NOTEL ( 24.25, 1.0, 70 ),
  NOTEL ( 24.5, 1.0, 74 ),
  NOTEL ( 26.5, 1.5, 77 ),
  NOTEL ( 26.5, 1.5, 72 ),
  NOTEL ( 26.5, 1.5, 69 ),
  // 7
  NOTEL ( 28.0, 2.0, 63 ),
  NOTEL ( 28.25, 1.75, 67 ),
  NOTEL ( 28.5, 1.5, 70 ),
  NOTEL ( 30.0, 2.0, 65 ),
  NOTEL ( 30.25, 1.75, 69 ),
  NOTEL ( 30.5, 1.5, 72 ),
  // 8
  NOTEL ( 32.0, 0.5, 74 ),
  NOTEL ( 32.0, 0.5, 70 ),
  NOTEL ( 32.0, 0.5, 67 ),
  NOTEL ( 33.5, 0.5, 74 ),
  NOTEL ( 33.5, 0.5, 72 ),
  NOTEL ( 33.5, 0.5, 69 ),
  NOTEL ( 35.0, 0.5, 79 ),
  NOTEL ( 35.0, 0.5, 74 ),
  NOTEL ( 35.0, 0.5, 70 ),
  NOTEL ( 35.5, 0.25, 74 ),
  NOTEL ( 35.75, 0.25, 77 ),
  // 9
  NOTEL ( 36.0, 2.0, 79 ),
  NOTEL ( 36.5, 0.5, 70 ),
  NOTEL ( 37.0, 0.5, 69 ),
  NOTEL ( 37.5, 0.5, 67 ),
  NOTEL ( 38.0, 2.0, 69 ),
  NOTEL ( 38.5, 0.5, 72 ),
  NOTEL ( 39.0, 0.5, 77 ),
  NOTEL ( 39.5, 0.5, 81 ),
  // 10
  NOTEL ( 40.0, 2.0, 79 ),
  NOTEL ( 40.5, 0.5, 74 ),
  NOTEL ( 41.0, 0.5, 70 ),
  NOTEL ( 41.5, 0.5, 69 ),
  NOTEL ( 42.0, 0.5, 67 ),
  NOTEL ( 42.5, 1.5, 67 ),
  NOTEL ( 43.0, 0.5, 72 ),
  NOTEL ( 43.5, 0.5, 77 ),
  // 11
  NOTEL ( 44.0, 2.0, 63 ),
  NOTEL ( 44.25, 1.75, 67 ),
  NOTEL ( 44.5, 1.5, 70 ),
  NOTEL ( 45.0, 1.0, 75 ),
  NOTEL ( 45.5, 0.5, 79 ),
  NOTEL ( 46.0, 2.0, 65 ),
  NOTEL ( 46.25, 1.75, 69 ),
  NOTEL ( 46.5, 1.5, 72 ),
  NOTEL ( 47.0, 1.0, 77 ),
  NOTEL ( 47.5, 0.5, 81 ),
  // 12
  NOTEL ( 48.0, 0.5, 74 ),
  NOTEL ( 48.0, 0.5, 70 ),
  NOTEL ( 48.0, 0.5, 67 ),
  NOTEL ( 48.0, 0.5, 62 ),
  NOTEL ( 50.5, 1.5, 72 ),
  NOTEL ( 50.5, 1.5, 69 ),
  NOTEL ( 50.5, 1.5, 65 ),
  // 13
  NOTEL ( 52.0, 2.0, 75 ),
  NOTEL ( 52.5, 0.5, 70 ),
  NOTEL ( 53.0, 0.5, 69 ),
  NOTEL ( 53.5, 0.5, 63 ),
  NOTEL ( 54.0, 2.0, 66 ),
  NOTEL ( 54.5, 0.5, 69 ),
  NOTEL ( 55.0, 0.5, 72 ),
  NOTEL ( 55.5, 0.5, 78 ),
  // 14
  NOTEL ( 56.0, 2.0, 79 ),
  NOTEL ( 56.5, 0.5, 74 ),
  NOTEL ( 57.0, 0.5, 70 ),
  NOTEL ( 57.5, 0.5, 69 ),
  NOTEL ( 58.0, 0.5, 67 ),
  NOTEL ( 58.5, 1.5, 67 ),
  NOTEL ( 59.0, 0.5, 72 ),
  NOTEL ( 59.5, 0.5, 77 ),
  //15
  NOTEL ( 60.0, 2.0, 63 ),
  NOTEL ( 60.25, 1.75, 67 ),
  NOTEL ( 60.5, 1.5, 70 ),
  NOTEL ( 61.0, 1.0, 75 ),
  NOTEL ( 61.5, 0.5, 79 ),
  NOTEL ( 62.0, 2.0, 65 ),
  NOTEL ( 62.25, 1.75, 69 ),
  NOTEL ( 62.5, 1.5, 72 ),
  NOTEL ( 63.0, 1.0, 77 ),
  NOTEL ( 63.5, 0.5, 81 ),
  // 16
  NOTEL ( 64.0, 2.0, 79 ),
  NOTEL ( 64.0, 0.5, 74 ),
  NOTEL ( 64.0, 0.5, 70 ),
  NOTEL ( 64.0, 0.5, 67 ),
  NOTEL ( 65.5, 0.5, 79 ),
  NOTEL ( 65.5, 1.5, 74 ),
  NOTEL ( 65.5, 0.5, 70 ),
  NOTEL ( 65.5, 0.5, 67 ),
  NOTEL ( 67.0, 0.5, 79 ),
  NOTEL ( 67.0, 1.5, 74 ),
  NOTEL ( 67.0, 0.5, 70 ),
  NOTEL ( 67.0, 0.5, 67 ),
  // 17
  NOTEL ( 68.0, 2.0, 79 ),
  NOTEL ( 68.5, 0.5, 70 ),
  NOTEL ( 69.0, 0.5, 69 ),
  NOTEL ( 69.5, 0.5, 67 ),
  NOTEL ( 70.0, 2.0, 69 ),
  NOTEL ( 70.5, 0.5, 72 ),
  NOTEL ( 71.0, 0.5, 77 ),
  NOTEL ( 71.5, 0.5, 81 ),
  // 18
  NOTEL ( 72.0, 2.0, 79 ),
  NOTEL ( 72.5, 0.5, 74 ),
  NOTEL ( 73.0, 0.5, 70 ),
  NOTEL ( 73.5, 0.5, 69 ),
  NOTEL ( 74.0, 0.5, 67 ),
  NOTEL ( 74.5, 1.5, 67 ),
  NOTEL ( 75.0, 0.5, 72 ),
  NOTEL ( 75.5, 0.5, 77 ),
  // 19
  NOTEL ( 76.0, 2.0, 63 ),
  NOTEL ( 76.25, 1.75, 67 ),
  NOTEL ( 76.5, 1.5, 70 ),
  NOTEL ( 77.0, 1.0, 75 ),
  NOTEL ( 77.5, 0.5, 79 ),
  NOTEL ( 78.0, 2.0, 65 ),
  NOTEL ( 78.25, 1.75, 69 ),
  NOTEL ( 78.5, 1.5, 72 ),
  NOTEL ( 79.0, 1.0, 77 ),
  NOTEL ( 79.5, 0.5, 81 ),
  // 20
  NOTEL ( 80.0, 0.5, 74 ),
  NOTEL ( 80.5, 0.5, 70 ),
  NOTEL ( 80.0, 0.5, 67 ),
  NOTEL ( 80.0, 0.5, 62 ),
  NOTEL ( 82.5, 1.5, 72 ),
  NOTEL ( 82.5, 1.5, 69 ),
  NOTEL ( 82.5, 1.5, 65 ),
  // 21
  NOTEL ( 84.0, 2.0, 75 ),
  NOTEL ( 84.5, 0.5, 70 ),
  NOTEL ( 85.0, 0.5, 69 ),
  NOTEL ( 85.5, 0.5, 63 ),
  NOTEL ( 86.0, 2.0, 66 ),
  NOTEL ( 86.5, 0.5, 69 ),
  NOTEL ( 87.0, 0.5, 72 ),
  NOTEL ( 87.5, 0.5, 78 ),
  // 22
  NOTEL ( 88.0, 2.0, 79 ),
  NOTEL ( 88.5, 0.5, 74 ),
  NOTEL ( 89.0, 0.5, 70 ),
  NOTEL ( 89.5, 0.5, 69 ),
  NOTEL ( 90.0, 0.5, 67 ),
  NOTEL ( 90.5, 1.5, 67 ),
  NOTEL ( 91.0, 0.5, 72 ),
  NOTEL ( 91.5, 0.5, 77 ),
  // 23
  NOTEL ( 92.0, 2.0, 63 ),
  NOTEL ( 92.25, 1.75, 67 ),
  NOTEL ( 92.5, 1.5, 70 ),
  NOTEL ( 93.0, 1.0, 75 ),
  NOTEL ( 93.5, 0.5, 79 ),
  NOTEL ( 94.0, 2.0, 65 ),
  NOTEL ( 94.25, 1.75, 69 ),
  NOTEL ( 94.5, 1.5, 72 ),
  NOTEL ( 95.0, 1.0, 77 ),
  NOTEL ( 95.5, 0.5, 81 ),
  // 24
  NOTEL ( 96.0, 2.0, 79 ),
  NOTEL ( 96.0, 0.5, 74 ),
  NOTEL ( 96.0, 0.5, 70 ),
  NOTEL ( 96.0, 0.5, 67 ),
  NOTEL ( 97.5, 0.5, 79 ),
  NOTEL ( 97.5, 1.5, 74 ),
  NOTEL ( 97.5, 0.5, 70 ),
  NOTEL ( 97.5, 0.5, 67 ),
  NOTEL ( 99.0, 0.5, 79 ),
  NOTEL ( 99.0, 1.5, 74 ),
  NOTEL ( 99.0, 0.5, 70 ),
  NOTEL ( 99.0, 0.5, 67 ),

  END_NOTE( 104 )
};

// ブラス楽譜
static const NoteData brass_score[] = {
  // 8
  NOTE ( 32.0, 0.5, 58 ),
  NOTE ( 32.0, 0.5, 55 ),
  NOTE ( 32.0, 0.5, 50 ),
  NOTE ( 33.5, 0.75, 58 ),
  NOTE ( 33.5, 0.75, 55 ),
  NOTE ( 33.5, 0.75, 50 ),
  NOTE ( 34.5, 0.25, 58 ),
  NOTE ( 34.5, 0.25, 55 ),
  NOTE ( 34.5, 0.25, 50 ),
  // 9
  NOTE ( 36.5, 0.25, 58 ),
  NOTE ( 36.5, 0.25, 55 ),
  NOTE ( 36.5, 0.25, 51 ),
  NOTE ( 37.5, 0.25, 58 ),
  NOTE ( 37.5, 0.25, 55 ),
  NOTE ( 37.5, 0.25, 51 ),
  NOTE ( 38.5, 0.25, 60 ),
  NOTE ( 38.5, 0.25, 57 ),
  NOTE ( 38.5, 0.25, 53 ),
  NOTE ( 39.5, 0.25, 60 ),
  NOTE ( 39.5, 0.25, 57 ),
  NOTE ( 39.5, 0.25, 53 ),
  // 10
  NOTE ( 40.5, 0.25, 62 ),
  NOTE ( 40.5, 0.25, 58 ),
  NOTE ( 40.5, 0.25, 55 ),
  NOTE ( 40.5, 0.25, 50 ),
  NOTE ( 41.5, 0.25, 62 ),
  NOTE ( 41.5, 0.25, 58 ),
  NOTE ( 41.5, 0.25, 55 ),
  NOTE ( 41.5, 0.25, 50 ),
  NOTE ( 42.5, 0.25, 60 ),
  NOTE ( 42.5, 0.25, 57 ),
  NOTE ( 42.5, 0.25, 53 ),
  NOTE ( 43.5, 0.25, 60 ),
  NOTE ( 43.5, 0.25, 57 ),
  NOTE ( 43.5, 0.25, 53 ),
  // 11
  NOTE ( 44.5, 0.25, 58 ),
  NOTE ( 44.5, 0.25, 55 ),
  NOTE ( 44.5, 0.25, 51 ),
  NOTE ( 45.5, 0.25, 58 ),
  NOTE ( 45.5, 0.25, 55 ),
  NOTE ( 45.5, 0.25, 51 ),
  NOTE ( 46.5, 0.25, 60 ),
  NOTE ( 46.5, 0.25, 57 ),
  NOTE ( 46.5, 0.25, 53 ),
  NOTE ( 47.5, 0.25, 60 ),
  NOTE ( 47.5, 0.25, 57 ),
  NOTE ( 47.5, 0.25, 53 ),
  // 12
  NOTE ( 48.0, 0.5, 62 ),
  NOTE ( 48.0, 0.5, 58 ),
  NOTE ( 48.0, 0.5, 55 ),
  NOTE ( 48.0, 0.5, 50 ),
  // 13
  NOTE ( 52.5, 0.25, 58 ),
  NOTE ( 52.5, 0.25, 55 ),
  NOTE ( 52.5, 0.25, 51 ),
  NOTE ( 53.5, 0.25, 58 ),
  NOTE ( 53.5, 0.25, 55 ),
  NOTE ( 53.5, 0.25, 51 ),
  NOTE ( 54.5, 0.25, 60 ),
  NOTE ( 54.5, 0.25, 57 ),
  NOTE ( 54.5, 0.25, 54 ),
  NOTE ( 55.5, 0.25, 60 ),
  NOTE ( 55.5, 0.25, 57 ),
  NOTE ( 55.5, 0.25, 54 ),
  // 14
  NOTE ( 56.5, 0.25, 62 ),
  NOTE ( 56.5, 0.25, 58 ),
  NOTE ( 56.5, 0.25, 55 ),
  NOTE ( 56.5, 0.25, 50 ),
  NOTE ( 57.5, 0.25, 62 ),
  NOTE ( 57.5, 0.25, 58 ),
  NOTE ( 57.5, 0.25, 55 ),
  NOTE ( 57.5, 0.25, 50 ),
  NOTE ( 58.5, 0.25, 60 ),
  NOTE ( 58.5, 0.25, 57 ),
  NOTE ( 58.5, 0.25, 53 ),
  NOTE ( 59.5, 0.25, 60 ),
  NOTE ( 59.5, 0.25, 57 ),
  NOTE ( 59.5, 0.25, 53 ),
  // 15
  NOTE ( 60.5, 0.25, 58 ),
  NOTE ( 60.5, 0.25, 55 ),
  NOTE ( 60.5, 0.25, 51 ),
  NOTE ( 61.5, 0.25, 58 ),
  NOTE ( 61.5, 0.25, 55 ),
  NOTE ( 61.5, 0.25, 51 ),
  NOTE ( 62.5, 0.25, 60 ),
  NOTE ( 62.5, 0.25, 57 ),
  NOTE ( 62.5, 0.25, 53 ),
  NOTE ( 63.5, 0.25, 60 ),
  NOTE ( 63.5, 0.25, 57 ),
  NOTE ( 63.5, 0.25, 53 ),
  // 16
  NOTE ( 64.0, 0.5, 62 ),
  NOTE ( 64.0, 0.5, 58 ),
  NOTE ( 64.0, 0.5, 55 ),
  NOTE ( 64.0, 0.5, 50 ),
  NOTE ( 65.5, 0.75, 62 ),
  NOTE ( 65.5, 0.75, 58 ),
  NOTE ( 65.5, 0.75, 55 ),
  NOTE ( 65.5, 0.75, 50 ),
  NOTE ( 66.5, 0.25, 58 ),
  NOTE ( 66.5, 0.25, 55 ),
  NOTE ( 66.5, 0.25, 50 ),
  NOTE ( 67.5, 0.25, 58 ),
  NOTE ( 67.5, 0.25, 55 ),
  NOTE ( 67.5, 0.25, 50 ),
  NOTE ( 67.5, 0.25, 74 ),//
  NOTE ( 67.75, 0.25, 77 ),//
  // 17
  NOTE ( 68.0, 2.0, 79 ),//
  NOTE ( 68.5, 0.25, 58 ),
  NOTE ( 68.5, 0.25, 55 ),
  NOTE ( 68.5, 0.25, 51 ),
  NOTE ( 69.5, 0.25, 58 ),
  NOTE ( 69.5, 0.25, 55 ),
  NOTE ( 69.5, 0.25, 51 ),
  NOTE ( 70.5, 1.5, 81 ),//
  NOTE ( 70.5, 0.25, 60 ),
  NOTE ( 70.5, 0.25, 57 ),
  NOTE ( 70.5, 0.25, 53 ),
  NOTE ( 71.5, 0.25, 60 ),
  NOTE ( 71.5, 0.25, 57 ),
  NOTE ( 71.5, 0.25, 53 ),
  // 18
  NOTE ( 72.0, 0.66666, 82 ),//
  NOTE ( 72.5, 0.25, 62 ),
  NOTE ( 72.5, 0.25, 58 ),
  NOTE ( 72.5, 0.25, 55 ),
  NOTE ( 72.5, 0.25, 50 ),
  NOTE ( 72.66666, 0.66666, 81 ),//
  NOTE ( 73.33333, 0.66666, 79 ),//
  NOTE ( 73.5, 0.25, 62 ),
  NOTE ( 73.5, 0.25, 58 ),
  NOTE ( 73.5, 0.25, 55 ),
  NOTE ( 73.5, 0.25, 50 ),
  NOTE ( 74.0, 0.66666, 74 ),//
  NOTE ( 74.5, 0.25, 60 ),
  NOTE ( 74.5, 0.25, 57 ),
  NOTE ( 74.5, 0.25, 53 ),
  NOTE ( 74.66666, 0.66666, 77 ),//
  NOTE ( 75.33333, 0.66666, 79 ),//
  NOTE ( 75.5, 0.25, 60 ),
  NOTE ( 75.5, 0.25, 57 ),
  NOTE ( 75.5, 0.25, 53 ),
  // 19
  NOTE ( 76.0, 0.25, 74 ),//
  NOTE ( 76.25, 0.25, 70 ),//
  NOTE ( 76.5, 0.25, 65 ),//
  NOTE ( 76.5, 0.25, 58 ),
  NOTE ( 76.5, 0.25, 55 ),
  NOTE ( 76.5, 0.25, 51 ),
  NOTE ( 76.75, 1.25, 67 ),//
  NOTE ( 77.5, 0.25, 58 ),
  NOTE ( 77.5, 0.25, 55 ),
  NOTE ( 77.5, 0.25, 51 ),
  NOTE ( 78.5, 1.5, 69 ),//
  NOTE ( 78.5, 0.25, 60 ),
  NOTE ( 78.5, 0.25, 57 ),
  NOTE ( 78.5, 0.25, 53 ),
  NOTE ( 79.5, 0.25, 60 ),
  NOTE ( 79.5, 0.25, 57 ),
  NOTE ( 79.5, 0.25, 53 ),
  // 20
  NOTE ( 80.0, 0.5, 70 ),//
  NOTE ( 80.0, 0.5, 62 ),
  NOTE ( 80.0, 0.5, 58 ),
  NOTE ( 80.0, 0.5, 55 ),
  NOTE ( 80.0, 0.5, 50 ),
  NOTE ( 82.0, 0.25, 70 ),//
  NOTE ( 82.25, 0.25, 69 ),//
  NOTE ( 82.5, 0.75, 65 ),//
  NOTE ( 83.5, 0.5, 65 ),//
  // 21
  NOTE ( 84.0, 0.5, 67 ),//
  NOTE ( 84.5, 0.5, 65 ),//
  NOTE ( 84.5, 0.25, 58 ),
  NOTE ( 84.5, 0.25, 55 ),
  NOTE ( 84.5, 0.25, 51 ),
  NOTE ( 85.5, 0.5, 70 ),//
  NOTE ( 85.5, 0.25, 58 ),
  NOTE ( 85.5, 0.25, 55 ),
  NOTE ( 85.5, 0.25, 51 ),
  NOTE ( 86.5, 0.5, 66 ),//
  NOTE ( 86.5, 0.25, 60 ),
  NOTE ( 86.5, 0.25, 57 ),
  NOTE ( 86.5, 0.25, 54 ),
  NOTE ( 87.0, 0.5, 74 ),//
  NOTE ( 87.5, 0.5, 78 ),//
  NOTE ( 87.5, 0.25, 60 ),
  NOTE ( 87.5, 0.25, 57 ),
  NOTE ( 87.5, 0.25, 54 ),
  // 22
  NOTE ( 88.0, 0.25, 79 ),//
  NOTE ( 88.25, 0.25, 81 ),//
  NOTE ( 88.5, 0.25, 82 ),//
  NOTE ( 88.5, 0.25, 62 ),
  NOTE ( 88.5, 0.25, 58 ),
  NOTE ( 88.5, 0.25, 55 ),
  NOTE ( 88.5, 0.25, 50 ),
  NOTE ( 88.75, 0.25, 84 ),//
  NOTE ( 89.0, 0.25, 82 ),//
  NOTE ( 89.25, 0.25, 81 ),//
  NOTE ( 89.5, 0.25, 74 ),//
  NOTE ( 89.5, 0.25, 62 ),
  NOTE ( 89.5, 0.25, 58 ),
  NOTE ( 89.5, 0.25, 55 ),
  NOTE ( 89.5, 0.25, 50 ),
  NOTE ( 89.75, 0.25, 79 ),//
  NOTE ( 90.5, 0.25, 74 ),//
  NOTE ( 90.5, 0.25, 60 ),
  NOTE ( 90.5, 0.25, 57 ),
  NOTE ( 90.5, 0.25, 53 ),
  NOTE ( 90.75, 0.25, 74 ),//
  NOTE ( 91.0, 0.25, 72 ),//
  NOTE ( 91.5, 0.25, 74 ),//
  NOTE ( 91.5, 0.25, 60 ),
  NOTE ( 91.5, 0.25, 57 ),
  NOTE ( 91.5, 0.25, 53 ),
  NOTE ( 91.75, 0.25, 70 ),//
  // 23
  NOTE ( 92.0, 0.5, 67 ),//
  NOTE ( 92.0, 0.75, 69 ),//
  NOTE ( 92.5, 0.25, 58 ),
  NOTE ( 92.5, 0.25, 55 ),
  NOTE ( 92.5, 0.25, 51 ),
  NOTE ( 93.25, 0.25, 70 ),//
  NOTE ( 93.5, 0.75, 74 ),//
  NOTE ( 93.5, 0.25, 58 ),
  NOTE ( 93.5, 0.25, 55 ),
  NOTE ( 93.5, 0.25, 51 ),
  NOTE ( 94.25, 0.25, 79 ),//
  NOTE ( 94.5, 0.5, 81 ),//
  NOTE ( 94.5, 0.25, 60 ),
  NOTE ( 94.5, 0.25, 57 ),
  NOTE ( 94.5, 0.25, 53 ),
  NOTE ( 95.0, 0.5, 82 ),//
  NOTE ( 95.5, 0.5, 86 ),//
  NOTE ( 95.5, 0.25, 60 ),
  NOTE ( 95.5, 0.25, 57 ),
  NOTE ( 95.5, 0.25, 53 ),
  // 24
  NOTE ( 96.0, 0.5, 82 ),//
  NOTE ( 96.0, 0.5, 79 ),//
  NOTE ( 96.0, 0.5, 74 ),//
  NOTE ( 96.0, 0.5, 62 ),
  NOTE ( 96.0, 0.5, 58 ),
  NOTE ( 96.0, 0.5, 55 ),
  NOTE ( 96.0, 0.5, 50 ),
  NOTE ( 97.5, 1.0, 84 ),//
  NOTE ( 97.5, 1.0, 79 ),//
  NOTE ( 97.5, 1.0, 74 ),//
  NOTE ( 97.5, 0.75, 62 ),
  NOTE ( 97.5, 0.75, 58 ),
  NOTE ( 97.5, 0.75, 55 ),
  NOTE ( 97.5, 0.75, 50 ),
  NOTE ( 99.0, 1.0, 82 ),//

  END_NOTE( 104 )
};

// ドラム楽譜
static const NoteData drum_score[] = {
  // 0
  NOTE ( 0.0, 1, 51 ),
  NOTE ( 1.5, 1, 51 ),
  NOTE ( 2.0, 1, 42 ),
  NOTE ( 2.5, 1, 42 ),
  NOTE ( 2.75, 1, 42 ),
  NOTE ( 3.5, 1, 46 ),
  NOTE ( 3.75, 1, 42 ),
  // 1
  NOTE ( 4.0, 1, 42 ),
  NOTE ( 4.25, 1, 42 ),
  NOTE ( 4.75, 1, 42 ),
  NOTE ( 5.0, 1, 42 ),
  NOTE ( 5.5, 1, 46 ),
  NOTE ( 6.0, 1, 42 ),
  NOTE ( 6.25, 1, 42 ),
  NOTE ( 6.5, 1, 46 ),
  NOTE ( 6.75, 1, 42 ),
  NOTE ( 7.5, 1, 46 ),
  NOTE ( 7.75, 1, 42 ),
  // 2
  NOTE ( 8.0, 1, 42 ),
  NOTE ( 8.75, 1, 42 ),
  NOTE ( 9.0, 1, 42 ),
  NOTE ( 9.5, 1, 46 ),
  NOTE ( 10.0, 1, 42 ),
  NOTE ( 10.0, 1, 36 ),
  NOTE ( 10.5, 1, 42 ),
  NOTE ( 10.75, 1, 42 ),
  NOTE ( 11.5, 1, 46 ),
  NOTE ( 11.75, 1, 42 ),
  // 3
  NOTE ( 12.0, 1, 42 ),
  NOTE ( 12.25, 1, 42 ),
  NOTE ( 12.75, 1, 42 ),
  NOTE ( 13.5, 1, 46 ),
  NOTE ( 13.75, 1, 42 ),
  NOTE ( 14.0, 1, 42 ),
  NOTE ( 14.25, 1, 42 ),
  NOTE ( 14.5, 1, 46 ),
  NOTE ( 14.75, 1, 42 ),
  NOTE ( 15.5, 1, 46 ),
  // 4
  NOTE ( 16.0, 1, 42 ),
  NOTE ( 16.5, 1, 46 ),
  NOTE ( 17.0, 1, 42 ),
  NOTE ( 17.25, 1, 42 ),
  NOTE ( 17.5, 1, 42 ),
  NOTE ( 17.75, 1, 42 ),
  NOTE ( 18.0, 1, 46 ),
  NOTE ( 18.5, 1, 42 ),
  NOTE ( 18.75, 1, 42 ),
  NOTE ( 19.0, 1, 42 ),
  NOTE ( 19.75, 1, 46 ),
  // 5
  NOTE ( 20.0, 1, 42 ),
  NOTE ( 20.25, 1, 42 ),
  NOTE ( 20.75, 1, 42 ),
  NOTE ( 21.0, 1, 42 ),
  NOTE ( 21.5, 1, 46 ),
  NOTE ( 22.0, 1, 42 ),
  NOTE ( 22.25, 1, 42 ),
  NOTE ( 22.5, 1, 46 ),
  NOTE ( 23.0, 1, 42 ),
  NOTE ( 23.5, 1, 46 ),
  // 6
  NOTE ( 24.0, 1, 42 ),
  NOTE ( 24.75, 1, 42 ),
  NOTE ( 25.0, 1, 42 ),
  NOTE ( 25.5, 1, 46 ),
  NOTE ( 25.75, 1, 42 ),
  NOTE ( 26.0, 1, 42 ),
  NOTE ( 26.75, 1, 42 ),
  NOTE ( 27.0, 1, 42 ),
  NOTE ( 27.75, 1, 46 ),
  // 7
  NOTE ( 28.0, 1, 42 ),
  NOTE ( 28.25, 1, 42 ),
  NOTE ( 28.75, 1, 42 ),
  NOTE ( 29.0, 1, 42 ),
  NOTE ( 29.5, 1, 46 ),
  NOTE ( 30.0, 1, 42 ),
  NOTE ( 30.25, 1, 42 ),
  NOTE ( 30.5, 1, 46 ),
  NOTE ( 31.0, 1, 42 ),
  NOTE ( 31.0, 1, 30 ),
  NOTE ( 31.5, 1, 46 ),
  // 8
  NOTE ( 32.0, 1, 42 ),
  NOTE ( 32.5, 1, 42 ),
  NOTE ( 33.0, 1, 42 ),
  NOTE ( 33.75, 1, 42 ),
  NOTE ( 34.0, 1, 42 ),
  NOTE ( 34.75, 1, 42 ),
  NOTE ( 35.0, 1, 42 ),
  NOTE ( 35.5, 1, 46 ),
  NOTE ( 35.75, 1, 42 ),
  // 9
  NOTE ( 36.75, 1, 42 ),
  NOTE ( 37.0, 1, 42 ),
  NOTE ( 37.5, 1, 46 ),
  NOTE ( 38.0, 1, 42 ),
  NOTE ( 38.25, 1, 42 ),
  NOTE ( 38.5, 1, 46 ),
  NOTE ( 38.75, 1, 42 ),
  NOTE ( 39.5, 1, 46 ),
  NOTE ( 39.75, 1, 42 ),
  // 10
  NOTE ( 40.0, 1, 42 ),
  NOTE ( 40.75, 1, 42 ),
  NOTE ( 41.0, 1, 42 ),
  NOTE ( 41.5, 1, 46 ),
  NOTE ( 42.0, 1, 42 ),
  NOTE ( 42.5, 1, 42 ),
  NOTE ( 42.75, 1, 42 ),
  NOTE ( 43.5, 1, 46 ),
  NOTE ( 43.75, 1, 42 ),
  // 11
  NOTE ( 44.0, 1, 42 ),
  NOTE ( 44.25, 1, 42 ),
  NOTE ( 44.75, 1, 42 ),
  NOTE ( 45.5, 1, 46 ),
  NOTE ( 45.75, 1, 42 ),
  NOTE ( 46.0, 1, 42 ),
  NOTE ( 46.25, 1, 42 ),
  NOTE ( 46.5, 1, 46 ),
  NOTE ( 46.75, 1, 42 ),
  NOTE ( 47.5, 1, 46 ),
  // 12
  NOTE ( 48.0, 1, 42 ),
  NOTE ( 48.5, 1, 46 ),
  NOTE ( 49.0, 1, 42 ),
  NOTE ( 49.0, 1, 29 ),
  NOTE ( 49.25, 1, 42 ),
  NOTE ( 49.5, 1, 42 ),
  NOTE ( 49.5, 1, 30 ),
  NOTE ( 49.75, 1, 42 ),
  NOTE ( 49.75, 1, 30 ),
  NOTE ( 50.0, 1, 46 ),
  NOTE ( 50.125, 1, 30 ),
  NOTE ( 50.5, 1, 42 ),
  NOTE ( 50.5, 1, 30 ),
  NOTE ( 50.75, 1, 42 ),
  NOTE ( 51.0, 1, 42 ),
  NOTE ( 51.75, 1, 46 ),
  // 13
  NOTE ( 52.0, 1, 42 ),
  NOTE ( 52.25, 1, 42 ),
  NOTE ( 52.75, 1, 42 ),
  NOTE ( 53.0, 1, 42 ),
  NOTE ( 53.5, 1, 46 ),
  NOTE ( 54.0, 1, 42 ),
  NOTE ( 54.25, 1, 42 ),
  NOTE ( 54.5, 1, 46 ),
  NOTE ( 55.0, 1, 42 ),
  NOTE ( 55.5, 1, 46 ),
  // 14
  NOTE ( 56.0, 1, 42 ),
  NOTE ( 56.75, 1, 42 ),
  NOTE ( 57.0, 1, 42 ),
  NOTE ( 57.5, 1, 46 ),
  NOTE ( 57.75, 1, 42 ),
  NOTE ( 58.0, 1, 42 ),
  NOTE ( 58.75, 1, 42 ),
  NOTE ( 59.0, 1, 42 ),
  NOTE ( 59.75, 1, 46 ),
  // 15
  NOTE ( 60.0, 1, 42 ),
  NOTE ( 60.25, 1, 42 ),
  NOTE ( 60.75, 1, 42 ),
  NOTE ( 61.0, 1, 42 ),
  NOTE ( 63.5, 1, 46 ),
  // 16
  NOTE ( 64.0, 1, 42 ),
  NOTE ( 64.5, 1, 42 ),
  NOTE ( 65.0, 1, 42 ),
  NOTE ( 65.75, 1, 42 ),
  NOTE ( 66.0, 1, 42 ),
  NOTE ( 66.75, 1, 42 ),
  NOTE ( 67.0, 1, 42 ),
  NOTE ( 67.5, 1, 46 ),
  NOTE ( 67.75, 1, 42 ),
  // 17
  NOTE ( 68.0, 1, 42 ),
  NOTE ( 68.25, 1, 42 ),
  NOTE ( 68.75, 1, 42 ),
  NOTE ( 69.0, 1, 42 ),
  NOTE ( 69.5, 1, 46 ),
  NOTE ( 70.0, 1, 42 ),
  NOTE ( 70.25, 1, 42 ),
  NOTE ( 70.5, 1, 46 ),
  NOTE ( 70.75, 1, 42 ),
  NOTE ( 71.5, 1, 46 ),
  NOTE ( 71.75, 1, 42 ),
  // 18
  NOTE ( 72.0, 1, 42 ),
  NOTE ( 72.75, 1, 42 ),
  NOTE ( 73.0, 1, 42 ),
  NOTE ( 73.5, 1, 46 ),
  NOTE ( 73.75, 1, 42 ),
  NOTE ( 74.0, 1, 42 ),
  NOTE ( 74.75, 1, 42 ),
  NOTE ( 75.0, 1, 42 ),
  NOTE ( 75.75, 1, 46 ),
  // 19
  NOTE ( 76.0, 1, 42 ),
  NOTE ( 76.25, 1, 42 ),
  NOTE ( 76.75, 1, 42 ),
  NOTE ( 77.5, 1, 46 ),
  NOTE ( 77.75, 1, 42 ),
  NOTE ( 78.0, 1, 42 ),
  NOTE ( 78.25, 1, 42 ),
  NOTE ( 78.5, 1, 46 ),
  NOTE ( 78.75, 1, 42 ),
  NOTE ( 79.0, 1, 46 ),
  // 20
  NOTE ( 80.0, 1, 42 ),
  NOTE ( 80.5, 1, 46 ),
  NOTE ( 81.0, 1, 42 ),
  NOTE ( 81.25, 1, 42 ),
  NOTE ( 81.5, 1, 42 ),
  NOTE ( 81.75, 1, 42 ),
  NOTE ( 82.0, 1, 46 ),
  NOTE ( 82.5, 1, 42 ),
  NOTE ( 82.75, 1, 42 ),
  NOTE ( 83.0, 1, 42 ),
  NOTE ( 83.75, 1, 46 ),
  // 21
  NOTE ( 84.0, 1, 42 ),
  NOTE ( 84.25, 1, 42 ),
  NOTE ( 84.75, 1, 42 ),
  NOTE ( 85.0, 1, 42 ),
  NOTE ( 85.5, 1, 46 ),
  NOTE ( 86.0, 1, 42 ),
  NOTE ( 86.25, 1, 42 ),
  NOTE ( 86.5, 1, 46 ),
  NOTE ( 87.0, 1, 42 ),
  NOTE ( 87.5, 1, 46 ),
  // 22
  NOTE ( 88.0, 1, 42 ),
  NOTE ( 88.25, 1, 42 ),
  NOTE ( 88.75, 1, 42 ),
  NOTE ( 89.5, 1, 46 ),
  NOTE ( 89.75, 1, 42 ),
  NOTE ( 90.0, 1, 42 ),
  NOTE ( 90.25, 1, 42 ),
  NOTE ( 90.5, 1, 46 ),
  NOTE ( 90.75, 1, 42 ),
  NOTE ( 91.0, 1, 46 ),
  // 23
  NOTE ( 92.0, 1, 42 ),
  NOTE ( 92.25, 1, 42 ),
  NOTE ( 92.75, 1, 42 ),
  NOTE ( 93.0, 1, 42 ),
  NOTE ( 93.5, 1, 46 ),
  NOTE ( 94.0, 1, 42 ),
  NOTE ( 94.25, 1, 42 ), NOTE ( 94.5, 1, 46 ),
  NOTE ( 95.0, 1, 42 ),
  NOTE ( 95.5, 1, 46 ),
  // 24
  NOTE ( 96.0, 1, 42 ),
  NOTE ( 96.75, 1, 42 ),
  NOTE ( 97.0, 1, 42 ),
  NOTE ( 98.5, 1, 46 ),
  NOTE ( 98.75, 1, 42 ),
  NOTE ( 99.0, 1, 42 ),
  NOTE ( 99.5, 1, 46 ),
  NOTE ( 99.75, 1, 42 ),

  END_NOTE( 104 )

};
#endif
