#include <tr1/cstdint>
#include <iostream>

#include "time.h"
#include "command.h"
#include "common.h"
#include "wave.h"

const double freq_table[ 12 ] = {
  32.70319566257483, 34.64782887210901, 36.70809598967594, 38.890872965260115,
  41.20344461410875, 43.653528929125486, 46.2493028389543, 48.999429497718666,
  51.91308719749314, 55, 58.27047018976124, 61.7354126570155,
};

    WaveBeep::WaveBeep( const char *_file_name )
    : current_tone( -1 ), current_freq( 1.0f ), current_time( 0.0 ) {
      output_file.reset( new std::fstream( _file_name, std::ios::out ) );
      const static char header[] = {
        'R', 'I', 'F', 'F',
        0x00, 0x00, 0x10, 0x00,
        'W', 'A', 'V','E',
        'f', 'm', 't', ' ',
        0x10, 0x00, 0x00, 0x00,
        0x01, 0x00,
        0x01, 0x00,
        (uint8_t)PLAYBACK_FREQUENCY, (uint8_t)( PLAYBACK_FREQUENCY >> 8 ), (uint8_t)( PLAYBACK_FREQUENCY >> 16 ), 
        (uint8_t)( PLAYBACK_FREQUENCY >> 24 ),
        (uint8_t)( PLAYBACK_FREQUENCY << 1 ), (uint8_t)( PLAYBACK_FREQUENCY >> 7 ),
        (uint8_t)( PLAYBACK_FREQUENCY >> 15 ), (uint8_t)( PLAYBACK_FREQUENCY >> 23 ),
        0x02, 0x00,
        0x10, 0x00,
        'd', 'a', 't', 'a',
        0x00, 0x00, 0x10, 0x00,
      };
      output_file->write( header, 48 );
      sample_count = 0;
    }
    WaveBeep::~WaveBeep() {
      unsigned int file_size = sample_count + 36;
      output_file->seekp( 4 );
      output_file->put( file_size & 0xFF );
      output_file->put( ( file_size >> 8 ) & 0xFF );
      output_file->put( ( file_size >> 16 ) & 0xFF );
      output_file->put( ( file_size >> 24 ) & 0xFF );
      output_file->seekp( 40 );
      output_file->put( sample_count & 0xFF );
      output_file->put( ( sample_count >> 8 ) & 0xFF );
      output_file->put( ( sample_count >> 16 ) & 0xFF );
      output_file->put( ( sample_count >> 24 ) & 0xFF );
    }
    void WaveBeep::setTone( int _new_tone ) {
      _new_tone &= 0x7F;
      _new_tone -= lowest_note_number;
      if( _new_tone > 0 ) {
        current_tone = _new_tone;
        current_freq = freq_table[ current_tone % 12 ] * ( 1 << ( current_tone / 12 ) );
      }
      else {
        current_tone = -1;
        current_freq = 1.0f;
      }
    }
    double WaveBeep::getTime() const {
      return current_time;
    }
    void WaveBeep::sleep( double _until ) {
      while( _until > current_time ) {
        signed short int temp = getWave();
        if( current_tone != -1 )
          output_file->write( (const char*)&temp, 2 );
        else {
          temp = -32767;
          output_file->write( (const char*)&temp, 2 );
        }
        sample_count+= 2;
      }
    }
    void WaveBeep::noize( double _until ) {
      while( _until > current_time ) {
        signed short int temp = getNoize();
        output_file->write( (const char*)&temp, 2 );
        sample_count+= 2;
      }
    }
    signed short int WaveBeep::getWave() {
      float temp = current_time * current_freq;
      current_time += 1.0 / PLAYBACK_FREQUENCY;
      temp = temp - (int)temp;
      if( temp > 0.5f ) return -32767;
      else return 32767;
    }
    signed short int WaveBeep::getNoize() {
      current_time += 1.0 / PLAYBACK_FREQUENCY;
      unsigned short int temp = random();
      if( temp > 0x7FFF ) return -32767;
      else return 32767;
    }
